TemplateRegistry class

Central registry for all UI templates available in the CLI

Constructors

TemplateRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

templates Map<String, TemplateDefinition>
Complete map of registered templates indexed by ID
final

Static Methods

getTemplate(String id) TemplateDefinition?
Retrieves a template definition by its unique ID