ApiTester class

Utilities for testing APIs from the CLI.

This module is used by the api test command to call endpoints and optionally generate models.

Constructors

ApiTester()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

callApi({required String url, required String method, Map<String, dynamic>? body}) Future<Map<String, dynamic>>
Sends an HTTP request to the provided API endpoint.