ApiTester class

Utility service responsible for making HTTP requests during CLI API testing.

It handles:

  • HTTP method routing
  • Request headers
  • Request body
  • Response parsing

Constructors

ApiTester()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

callApi({required String url, required String method, Map<String, dynamic>? body}) Future<Map<String, dynamic>>