FigmaService class
Constructors
- FigmaService(String token)
Properties
Methods
-
fetchFigmaFile(
String fileKey, {String? nodeId}) → Future< Map< String, dynamic> ?> - Fetches a figma file or specific nodes if nodeId is provided
-
getTopLevelFrames(
Map< String, dynamic> figmaJson) → List<Map< String, dynamic> > - Retrieves top-level frames from the Figma JSON
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
extractFileKey(
String input) → String? - Extracts the Figma File Key from a URL or returns the key if it's already one.
-
extractNodeId(
String url) → String? - Extracts the node-id from a figma URL